From: Andy Tai <atai@atai.org>
To: 62070@debbugs.gnu.org
Cc: Andy Tai <atai@atai.org>
Subject: [bug#62070] [PATCH] gnu: pocl: Update to 3.1
Date: Thu, 9 Mar 2023 16:47:15 -0800 [thread overview]
Message-ID: <20230310004715.11762-1-atai@atai.org> (raw)
In-Reply-To: <20230309090624.765-1-atai@atai.org>
* gnu/packages/opencl.scm (pocl): Update to 3.1
[native-inputs]: Add python-3
[arguments]: Update RPATH
---
gnu/packages/opencl.scm | 62 ++++++++++++++++++++++-------------------
1 file changed, 33 insertions(+), 29 deletions(-)
diff --git a/gnu/packages/opencl.scm b/gnu/packages/opencl.scm
index 2e506156b2..b25438ba98 100644
--- a/gnu/packages/opencl.scm
+++ b/gnu/packages/opencl.scm
@@ -279,38 +279,42 @@ (define-public beignet
(define-public pocl
(package
(name "pocl")
- (version "1.4")
- (source
- (origin
- (method git-fetch)
- (uri (git-reference
- (url "https://github.com/pocl/pocl")
- (commit (string-append "v" version))))
- (sha256
- (base32 "1c4y69zks6hkq5fqh9waxgb8g4ka7y6h3vacmsm720kba0h57g8a"))
- (file-name (git-file-name name version))))
+ (version "3.1")
+ (source (origin
+ (method git-fetch)
+ (uri (git-reference
+ (url "https://github.com/pocl/pocl")
+ (commit (string-append "v" version))))
+ (sha256
+ (base32
+ "1pw4q0hi5ynx34fvzryravz3jbh89f9cg60fkjj77sxh9xw8phdd"))
+ (file-name (git-file-name name version))))
(build-system cmake-build-system)
- (native-inputs
- (list libltdl pkg-config))
- (inputs
- (list clang-9 llvm-9 `(,hwloc-2 "lib") opencl-icd-loader))
+ (native-inputs (list libltdl pkg-config python-3))
+ (inputs (list clang-15 llvm-15
+ `(,hwloc-2 "lib") opencl-icd-loader))
(arguments
- `(#:configure-flags
- (list "-DENABLE_ICD=ON"
- "-DENABLE_TESTSUITES=ON"
- ;; We are not developers, don't run conformance suite.
- "-DENABLE_CONFORMANCE=OFF"
- (string-append "-DEXTRA_HOST_LD_FLAGS=-L"
- (assoc-ref %build-inputs "libc") "/lib"))
- #:phases
- (modify-phases %standard-phases
- (add-before 'check 'set-HOME
- (lambda _
- (setenv "HOME" "/tmp")
+ `(#:configure-flags (let* ((libdir (string-append (assoc-ref %outputs
+ "out")
+ "/lib")))
+ (list "-DENABLE_ICD=ON"
+ "-DENABLE_TESTSUITES=ON"
+ ;; We are not developers, don't run conformance suite.
+ "-DENABLE_CONFORMANCE=OFF"
+ (string-append "-DEXTRA_HOST_LD_FLAGS=-L"
+ (assoc-ref %build-inputs
+ "libc") "/lib")
+ ;; We need both libdir and libdir/pocl in RUNPATH.
+ (string-append "-DCMAKE_INSTALL_RPATH="
+ libdir ";" libdir "/pocl")))
+ #:phases (modify-phases %standard-phases
+ (add-before 'check 'set-HOME
+ (lambda _
+ (setenv "HOME" "/tmp")
- ;; Since 2.9.0, hwloc fails when /sys is missing, so provide a
- ;; fake topology.
- (setenv "HWLOC_SYNTHETIC" "4"))))))
+ ;; Since 2.9.0, hwloc fails when /sys is missing, so provide a
+ ;; fake topology.
+ (setenv "HWLOC_SYNTHETIC" "4"))))))
(home-page "http://portablecl.org/")
(synopsis "Portable Computing Language (pocl), an OpenCL implementation")
(description
base-commit: f289fe316aaa06e60f4b10e75e113cf1aeb03629
--
2.39.1
next prev parent reply other threads:[~2023-03-10 0:48 UTC|newest]
Thread overview: 9+ messages / expand[flat|nested] mbox.gz Atom feed top
2023-03-09 9:06 [bug#62070] [PATCH] gnu: pocl: Update to 3.1 Andy Tai
2023-03-10 0:47 ` Andy Tai [this message]
2023-03-12 9:07 ` [bug#62070] [PATCH v2] " Andy Tai via Guix-patches
2023-03-12 9:37 ` [bug#62070] [PATCH v3] " Andy Tai
2023-03-13 5:55 ` Andy Tai
2023-03-13 6:49 ` [bug#62070] [PATCH v4] " Andy Tai
2023-03-13 17:34 ` [bug#62070] [PATCH v5] " Andy Tai
2023-03-21 18:06 ` bug#62070: [PATCH] " Ludovic Courtès
2023-03-21 18:15 ` [bug#62070] " Andy Tai
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
List information: https://guix.gnu.org/
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20230310004715.11762-1-atai@atai.org \
--to=atai@atai.org \
--cc=62070@debbugs.gnu.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
Code repositories for project(s) associated with this public inbox
https://git.savannah.gnu.org/cgit/guix.git
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).